@@ -278,10 +278,11 @@ def should_promote_to_object(
             )
             if isinstance(result_type, np.dtype):
                 np_result_types.add(result_type)
-        except TypeError:
+        except (TypeError, ValueError):
             # passing individual objects to xp.result_type (i.e., what `array_api_compat.result_type` calls) means NEP-18 implementations won't have
             # a chance to intercept special values (such as NA) that numpy core cannot handle.
             # Thus they are considered as types that don't need promotion i.e., the `arr_or_dtype` that rose the `TypeError` will not contribute to `np_result_types`.
+            # Note: NumPy 2.x raises ValueError for dtypes it can't convert (e.g., PeriodDtype).
             pass
 
     if np_result_types:
