@@ -284,7 +284,7 @@ class FacetGrid(Generic[T_DataArrayOrSet]):
                 "self.axes is deprecated since 2022.11 in order to align with "
                 "matplotlibs plt.subplots, use self.axs instead."
             ),
-            DeprecationWarning,
+            FutureWarning,
             stacklevel=2,
         )
         return self.axs
@@ -296,7 +296,7 @@ class FacetGrid(Generic[T_DataArrayOrSet]):
                 "self.axes is deprecated since 2022.11 in order to align with "
                 "matplotlibs plt.subplots, use self.axs instead."
             ),
-            DeprecationWarning,
+            FutureWarning,
             stacklevel=2,
         )
         self.axs = axs
